@@ -62,3 +62,9 @@ impl Compressor {
         Ok(buffer)
     }
 }
+
+fn _assert_traits() {
+    fn _assert_send<T: Send>(_: T) {}
+
+    _assert_send(Compressor::new());
+}
